module siebensegment
(
    input clk,
    input [4:0] data0, // 4 Bit + Dezimalpunkt
    input [4:0] data1,
    input [4:0] data2,
    input [4:0] data3,
    output [7:0] segmente, // 7 Segmente + Dezimalpunkt
    output [3:0] anode
);

//Taktfrequenz fuer Segment-Umschaltung
wire clk_slow;
clockdivider #( .max_count(15624) ) myclockdivider
(
    .clk(clk),
    .clk_slow(clk_slow)
);

// Multiplexer Steuersignal
wire [1:0] count_digits;
counter #( .width(2) ) counter_digits
(
    .clk(clk_slow),
    .count(count_digits)
);

// Daten Multiplexer
wire [4:0] data_to_siebensegment;
assign data_to_siebensegment = (count_digits == 2'd0 ? data0 :
                               (count_digits == 2'd1 ? data1 :
                               (count_digits == 2'd2 ? data2 :
                               (count_digits == 2'd3 ? data3 :
                                5'bzzzzz ))));

//Daten zu 7-Seg Dekoder
siebensegment_dekoder dekoder
(
    .code(data_to_siebensegment),
    .segmente(segmente)
);

// Segment Select Multiplexer
assign anode = (count_digits == 2'd0 ? 4'b1110 :
               (count_digits == 2'd1 ? 4'b1101 :
               (count_digits == 2'd2 ? 4'b1011 :
               (count_digits == 2'd3 ? 4'b0111 :
                4'b1111 ))));

endmodule
