module stoppuhr_top
(
    input clk,
    input [3:0] button,
    output [7:0] segmente,
    output [3:0] anode,
    output led
);

// BTN3		BTN2		BTN1		BTN0
// start		stop		zwisch.	null

// Tasten entprellen
wire start, stopp, zwischenzeit, null;
wire [3:0] taste_entprellt, taste_posedge;

entprell_alle #(.max_count(500000)) entprell10ms
(
    .clk(clk),
    .taste(button),
    .taste_entprellt(taste_entprellt),
	 .taste_posedge(taste_posedge)
);

assign start = taste_posedge[3];
assign stopp = taste_posedge[2];
assign zwischenzeit = taste_posedge[1];
assign null = taste_entprellt[0];

// FSM fr count_en
wire count_en;
assign led = count_en;
count_en_FSM fsm1
(
    .clk(clk),
    .start(start),
    .stopp(stopp),
    .count_en(count_en)
);

// FSM fr update_display
update_display_FSM fsm2
(
    .clk(clk),
    .zwischenzeit(zwischenzeit),
    .null(null),
    .count_en(count_en),
    .update_display(update_display)
);

// Taktteiler 10 Hz = 100ms
wire clk10hz;
clockdivider #(.max_count(2499999)) clockdiv10hz
(
    .clk(clk),
    .clk_slow(clk10hz)
);

// 10 Hz Zhler mit 4-stelliger Ausgabe
wire [15:0] count_4digits;
counter_4digits mycounter
(
    .clk(clk10hz),
    .reset(null),
    .enable(count_en),
    .count_4digits(count_4digits)
);

// Zhlerstand auf Siebensegmentanzeige
reg [15:0] data_siebenseg;
always @(posedge clk) begin
    if (update_display == 1'b1)
        data_siebenseg <= count_4digits;
end

// Siebensegmentanzeige
siebensegment mysiebensegment
(
    .clk(clk),
    .data0({data_siebenseg[3:0],   1'b0}),
    .data1({data_siebenseg[7:4],   1'b1}),
    .data2({data_siebenseg[11:8],  1'b0}),
    .data3({data_siebenseg[15:12], 1'b1}),
    .segmente(segmente),
    .anode(anode)
);

endmodule
